District class
Constructors
-
District({required HongKongDistrict type, required String shortForm, required String name, required String chineseName, required List<
LatLng> latLngs}) -
District.fromJson(Map<
String, dynamic> json) -
factory
Properties
- chineseName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
latLngs
→ List<
LatLng> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortForm → String
-
final
- type → HongKongDistrict
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited